@@ -33,15 +33,18 @@ Q_OBJECT
 
 public:
     SpellCheckRunner(QObject* parent, const QVariantList &args);
-    ~SpellCheckRunner();
+    ~SpellCheckRunner() override;
 
-    void match(Plasma::RunnerContext &context) Q_DECL_OVERRIDE;
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) Q_DECL_OVERRIDE;
+    void match(Plasma::RunnerContext &context) override;
+    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;
 
-    void reloadConfiguration() Q_DECL_OVERRIDE;
+    void reloadConfiguration() override;
+
+protected Q_SLOTS:
+    void init() override;
+    QList<QAction *> actionsForMatch(const Plasma::QueryMatch &match) override;
+    QMimeData * mimeDataForMatch(const Plasma::QueryMatch &match) override;
 
-protected slots:
-    void init() Q_DECL_OVERRIDE;
     void loaddata();
     void destroydata();
 
